@@ -1,4 +1,13 @@
-package t::lib::Cases;
+#
+# This file is part of Capture-Tiny
+#
+# This software is Copyright (c) 2009 by David Golden.
+#
+# This is free software, licensed under:
+#
+#   The Apache License, Version 2.0, January 2004
+#
+package Cases;
 use strict;
 use warnings;
 use Test::More;
@@ -49,7 +58,7 @@ sub _restore_layers {
 my %texts = (
   short => 'Hello World',
   multiline => 'First line\nSecond line\n',
-  ( $] < 5.008 ? () : ( unicode => 'Hi! \x{263a}\n') ),
+  ( $] lt "5.008" ? () : ( unicode => 'Hi! \x{263a}\n') ),
 );
 
 #--------------------------------------------------------------------------#
@@ -181,6 +190,7 @@ my %tests = (
 sub run_test {
   my $test_type = shift or return;
   my $todo = shift || '';
+  local $ENV{PERL_CAPTURE_TINY_TIMEOUT} = 0; # don't timeout during testing
   for my $m ( keys %methods ) {
     for my $c ( keys %channels ) {
       for my $t ( keys %texts     ) {
