@@ -1,4 +1,13 @@
-package t::lib::TieLC;
+#
+# This file is part of Capture-Tiny
+#
+# This software is Copyright (c) 2009 by David Golden.
+#
+# This is free software, licensed under:
+#
+#   The Apache License, Version 2.0, January 2004
+#
+package TieLC;
 
 sub TIEHANDLE 
 {
